@@ -12,24 +12,25 @@ __status__ = "Development"
 
 import random
 
-def crossover_function_classic(mother, father, prob : float, island=None) -> tuple:
+def crossover_function_classic(individuals : list, prob : float, island=None) -> list:
     """
-    A Classic crossover function.
+    A Classic crossover function, taking a list of 2 individuals and swapping positional genes based on the `prob` strength of crossover.
+    Returns these two individuals with modified genomes.
 
     Args:
-        mother (Individual): Individual object containing a Genome.
-        father (Individual): Individual object containing a Genome.
+        individuals (list): A list (length of 2) of Individuals to perform crossover.
         prob (float): The probability of swapping genes.
         island (Island): The Island calling the method (optional, default = None).
 
     Returns:
-        tuple: Two new Individuals.
+        list: Two new Individuals.
     """
+    assert len(individuals) > 1, "Not enough individuals given!"
+    mother = individuals[0]
+    father = individuals[1]
     size = min(len(mother.genome), len(father.genome))
     for i in range(size):
         if random.random() < prob:
             mother.genome[i], father.genome[i] = father.genome[i], mother.genome[i]
-            mother.reset_fitness()
-            father.reset_fitness()
 
-    return mother, father
\ No newline at end of file
+    return [mother, father]
\ No newline at end of file
