@@ -29,4 +29,18 @@ def selection_function_classic(population : list, n : int, desc : bool = True, i
 
     population.sort(key=sortFitness, reverse=desc)
 
-    return population[0:n]
\ No newline at end of file
+    return population[0:n]
+
+def selection_function_parents_classic(population : list, island=None):
+    """
+    Simple function to select two parents at a time, sequentially.
+
+    Args:
+        population (list): A list of Individuals, specifically the selected "elites".
+        island (Island): The Island calling the method (optional, default = None).
+
+    Yields:
+        list: Containing the two individuals selected for crossover.
+    """
+    for parent_1, parent_2 in zip(population[::2], population[1::2]):
+        yield [parent_1, parent_2]
\ No newline at end of file
